@@ -725,7 +725,7 @@ def get_package_requirements(package_name: str) -> Iterable[str]:
     for line in output.split('\n'):
         if line.startswith('Requires:'):
             required_package_name: str
-            for required_package_name in line.lstrip().split(','):
+            for required_package_name in line[9:].lstrip().split(','):
                 yield required_package_name.strip().replace('_', '-')
             break
 
